==> lein-template-0.16.0.jar: leiningen/new/elbenwald_template/app/env/prod/clj/env.clj <==
(ns {{ns-name}}.env
  (:require
    [clojure.tools.logging :as l]
    [de.elbenwald.common.infra :as eci]
    [de.elbenwald.common.io :as ecio]
    [de.elbenwald.common.lang :refer :all]
    [de.elbenwald.common.utils :refer :all]
    [de.elbenwald.app-common.graphql :as acq]
    [de.elbenwald.fusion-auth.core :as fac]
    [de.elbenwald.fusion-auth.dummy :as fad]
    [{{ns-name}}.app :as app]
    [de.elbenwald.security.core :as esc]
    [plumbing.core :refer :all]))

(defn configure-fusion-auth-factory
  "TODO doc"
  [component-factory env]
  (letk [[[:fusion-auth
           factory
           options]] env]
    (case factory
      :fusion-auth/dummy
      (fad/configure-fusion-auth-factory component-factory options)

      :fusion-auth/genuine
      (fac/configure-fusion-auth-factory component-factory options))))

(defnk make-component-factory
  "TODO doc"
  [working-folder
   :as env]
  (-> (eci/new-common-component-factory)
    (configure-fusion-auth-factory env)
    (esc/configure-access-logging-factory {})
    (esc/configure-authentication-factory {})
    (esc/configure-authorization-factory {})
    (esc/configure-web-security-factory {})
    (acq/configure-graphql-factory {})
    (app/configure-app-factory {})
    (as-> $ (eci/new-component-factory {} $))))

(def defaults
  {:init
   (fn []
     (l/info "\n-=[{{ns-name}} started successfully]=-"))

   :stop
   (fn []
     (l/info "\n-=[{{ns-name}} has shut down successfully]=-"))

   :middleware identity
   :make-component-factory make-component-factory})

==> lein-template-0.25.0.jar: leiningen/new/elbenwald_template/app/env/prod/clj/env.clj <==
(ns {{ns-name}}.env
  (:require
    [clojure.tools.logging :as l]
    [de.elbenwald.app-common.graphql :as acq]
    [de.elbenwald.common.infra :as eci]
    [de.elbenwald.common.io :as ecio]
    [de.elbenwald.common.io.fs-repository :as eciofr]
    [de.elbenwald.common.io.http-repository :as eciohr]
    [de.elbenwald.common.lang :refer :all]
    [de.elbenwald.common.scheduling.scheduler-service :as ecsss]
    [de.elbenwald.common.utils :refer :all]
    [de.elbenwald.fusion-auth.core :as fac]
    [de.elbenwald.fusion-auth.dummy :as fad]
    [de.elbenwald.rabbitmq.core :as erc]
    [de.elbenwald.security.core :as esc]
    [{{ns-name}}.app :as app]
    [plumbing.core :refer :all]))

(defn configure-fusion-auth-factory
  "TODO doc"
  [component-factory env]
  (letk [[[:fusion-auth
           factory
           options]] env]
    (case factory
      :fusion-auth/dummy
      (fad/configure-fusion-auth-factory component-factory options)

      :fusion-auth/genuine
      (fac/configure-fusion-auth-factory component-factory options))))

(defnk make-component-factory
  "TODO doc"
  [:as env]
  (-> (eci/new-common-component-factory)
    (eciofr/configure-fs-repository-factory {})
    (eciohr/configure-http-repository-factory {})
    (ecsss/configure-scheduler-service-factory {})
    (erc/configure-rabbitmqem-factory {})
    (configure-fusion-auth-factory env)
    (esc/configure-access-logging-factory {})
    (esc/configure-authentication-factory {})
    (esc/configure-authorization-factory {})
    (esc/configure-web-security-factory {})
    (acq/configure-graphql-factory {})
    (app/configure-app-factory {})
    (as-> $ (eci/new-component-factory {} $))))

(def defaults
  {:init
   (fn []
     (l/info "\n-=[{{ns-name}} started successfully]=-"))

   :stop
   (fn []
     (l/info "\n-=[{{ns-name}} has shut down successfully]=-"))

   :middleware identity
   :make-component-factory make-component-factory})
